import React, { PureComponent } from 'react';
import './coupons.scss'

import ExchangeaBar from "./ExchangeBar";
import Coupon from './Coupon'
import { http, api } from '@/utils'
import { WithFullSize } from '@/HOCs'
import { Toast } from 'antd-mobile'


class UseCoupon extends PureComponent {

    state = {
        selectedCouponId: 0,
        exchangeCode: '',
        couponList: [],
        valid_coupons: [],
        invalid_coupons: [],
        courseId: 139,
    }

    componentDidMount() {
        const {state} = this.props.location
        if (state && state.from) {
            switch (state.from) {
                case '/my' :
                    this.getMyCoupons();
                    break;
                default:
                    this.getAllCoupons();
            }
        } else {
            this.getAllCoupons()
        }
    }

    select = val => {
        this.setState({
            selectedCouponId: val === this.state.selectedCouponId ? 0 : val
        })
    }

    handleChange = val => {
        this.setState({exchangeCode: val})
    }

    exchange = () => {
        if (this.state.exchangeCode !== '') {
            http.post(`${api.home}/m/coupon/exchange`, {
                code: this.state.exchangeCode
            })
                .then(res => {
                    const data = res.data
                    if (data.code === 200) {
                        this.setState({
                            couponList: [data.data, ...this.state.couponList]
                        })
                        Toast.info('兑换成功')
                    } else {
                        Toast.info(data.msg)
                    }
                })
        } else {
            Toast.info('请输入兑换码')
        }
    }

    getMyCoupons = () => {
        http.get(`${api.home}/m/coupon/all`)
            .then(res => {
                const data = res.data
                if (data.code === 200) {
                    this.setState({
                        couponList: data.data
                    })
                } else {
                    Toast.info(data.msg)
                }
            })
    }

    getAllCoupons = () => {
        http.post(`${api.home}/m/coupon/select`, {course_id: this.state.courseId})
            .then(res => {
                const data = res.data
                if (data.code === 200) {

                    const inuse_coupon = data.data.inuse_coupon;

                    this.setState({
                        valid_coupons: inuse_coupon
                            ? [...inuse_coupon, ...data.data.valid_coupons]
                            : data.data.valid_coupons,
                        invalid_coupons: data.data.invalid_coupons,
                        selectedCouponId: inuse_coupon ? inuse_coupon[0].id : 0
                    })

                } else {
                    Toast.info(data.msg)
                }
            })
    }

    useCoupon = (val) => {
        if (val) {
            http.post(`${api.home}/m/coupon/use`, {
                course_id: this.state.courseId,
                coupon_id: val
            })
                .then(res => {
                    const data = res && res.data
                    if (data.code === 200) {


                    } else {
                        Toast.info(data.msg)
                    }
                })
        }
    }

    render() {
        const {state} = this.props.location
        return (
            <div className='use-coupon'>
                <ExchangeaBar onChange={this.handleChange}
                              exchange={this.exchange}
                              exchangeCode={this.state.exchangeCode}/>
                <div className="coupons-area">
                    <Content
                        coupons={
                            state
                            && state.from
                            && state.from === '/my'
                                ? this.state.couponList
                                : this.state.valid_coupons
                        }
                        showUseButton={false}
                        selected={this.state.selected}
                        selectedCouponId={this.state.selectedCouponId}
                        select={this.select}
                        useCoupon={this.useCoupon}
                    />
                    {
                        this.state.invalid_coupons.length > 0 &&
                        (
                            <>
                                <div className='invalid-title'>- 不可使用的优惠券 -</div>
                                <Content
                                    coupons={this.state.invalid_coupons}
                                    selectedCouponId={this.state.selectedCouponId}
                                    select={this.select}
                                    purpose={'use'}
                                    invalid={'invalid'}
                                />
                            </>
                        )
                    }
                </div>
            </div>
        );
    }
}

function Content({coupons, ...rest}) {
    if (coupons.length === 0) {
        return (
            <div className='empty'>
                <p>暂无可使用的优惠券</p>
            </div>
        )
    }
    return (
        <ul>
            {
                coupons.map(item => {
                    return (
                        <Coupon
                            key={item.id}
                            {...item}
                            id={item.id}
                            {...rest}
                        />
                    )
                })
            }
        </ul>
    )
}

export default WithFullSize(UseCoupon);