import React, { PureComponent } from 'react'
import { Course, Tag } from '../../../common'
import { http, api } from '@/utils'


import './free-courses.scss'

const Bottom = (props) => (
    <div className='bottom'>
        <Tag className={props.className}>{props.text}</Tag>
        <span>{props.audience}人观看</span>
    </div>
)

class FreeCourse extends PureComponent {
    state = {
        courses: [],
        live: [],
        page: 1,
        num: 10
    }

    componentDidMount() {
        this.getFreeCourses()
            .then(res => {
                if (res.data.code == 200) {
                    this.setState({
                        courses: res.data.data,
                    })
                } else {
                    console.log(res.data.msg)
                }
            })
        this.getFreeLive()
            .then(res => {
                if (res.data.code == 200) {
                    this.setState({
                        live: res.data.data
                    })
                }
            })
    }

    getFreeCourses = () => {
        return http.get(`${api.home}/m/free_course/${this.state.page}/${this.state.num}`)
    }

    getFreeLive = () => {
        return http.get(`${api.home}/m/live/free_list`)
    }

    render() {
        return (
            <ul className='free-courses'>
                {
                    this.state.courses.map((item, index) => (
                        <Course
                            data={{
                                src: item.logo,
                                title: item.video_course_name
                            }}
                            bottom={
                                <Bottom audience={item.lessons} className={'tag-category'} text={item.category}/>
                            }
                            key={index}
                        >
                        </Course>
                    ))
                }
                {/*{
                    this.state.live.map((item,index) => (
                        <Course
                            data={{
                                src: item.live_img,
                                title: item.live_title
                            }}
                            top={
                                <Tag className={'tag-starting top'}>即将开始</Tag>
                            }
                            bottom={
                                <Bottom audience={item.lessons} className={'tag-category'} text={item.category}/>
                            }
                            key={item.live_id}
                        />
                    ))
                }*/}
            </ul>
        )
    }
}


export default FreeCourse